.. Zuice documentation master file, created by
   sphinx-quickstart on Sun Aug  9 14:05:07 2009.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Zuice's documentation!
=================================

Contents:

.. toctree::
   :maxdepth: 2
   
   quick_start
   zuice
   bindings

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

